writefrudata: rename all variables per openbmc style

OpenBMC style declares variables be lower camel and not snake case.

Change-Id: Iec348bf9825caecc976f654a37ac149a5981c94b
Signed-off-by: Patrick Venture <venture@google.com>
diff --git a/writefrudata.hpp b/writefrudata.hpp
index 072d4d3..cc5cef6 100644
--- a/writefrudata.hpp
+++ b/writefrudata.hpp
@@ -45,11 +45,11 @@
  * Validate a FRU.
  *
  * @param[in] fruid - The ID to use for this FRU.
  * @param[in] fru_file_name - the filename of the FRU.
  * @param[in] bus - an sdbusplus systemd bus for publishing the information.
  * @param[in] bmc_fru - If a particular area accessible only by BMC.
  */
-int validateFRUArea(const uint8_t fruid, const char* fru_file_name,
-                    sdbusplus::bus::bus& bus, const bool bmc_fru);
+int validateFRUArea(const uint8_t fruid, const char* fruFilename,
+                    sdbusplus::bus::bus& bus, const bool bmcOnlyFru);
 
 #endif
@@ -45,11 +45,11 @@
  *
  * @param[in] fruid - The ID to use for this FRU.
- * @param[in] fru_file_name - the filename of the FRU.
+ * @param[in] fruFilename - the filename of the FRU.
  * @param[in] bus - an sdbusplus systemd bus for publishing the information.
@@ -45,11 +45,11 @@
  * @param[in] bus - an sdbusplus systemd bus for publishing the information.
- * @param[in] bmc_fru - If a particular area accessible only by BMC.
+ * @param[in] bmcOnlyFru - If a particular area accessible only by BMC.
  */